@@ -19,6 +19,9 @@ from sars2seq.translate import NoSlipperySequenceError
 from .fasta import getSequence
 
 
+ALPHA_ID = 'EPI_ISL_601443 hCoV-19/England/MILK-9E05B3/2020'
+
+
 class TestSARS2Genome(TestCase):
     """
     Test the SARS2Genome class.
@@ -642,13 +645,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'V',
                     'codon': 'GTT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'refId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 },
                 'genome': {
                     'aa': 'I',
                     'codon': 'ATT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'genId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 }
             },
             genome.offsetInfo(0))
@@ -679,13 +686,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'V',
                     'codon': 'GTT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'refId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 },
                 'genome': {
                     'aa': 'I',
                     'codon': 'ATT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'genId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 }
             },
             genome.offsetInfo(0))
@@ -716,13 +727,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'P',
                     'codon': 'CCC',
                     'frame': 2,
-                    'offset': 5,
+                    'id': 'refId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 },
                 'genome': {
                     'aa': 'P',
                     'codon': 'CCC',
                     'frame': 2,
-                    'offset': 5,
+                    'id': 'genId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 }
             },
             genome.offsetInfo(5))
@@ -753,13 +768,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'X',
                     'codon': 'A',
                     'frame': 0,
-                    'offset': 6,
+                    'id': 'refId',
+                    'aaOffset': 2,
+                    'ntOffset': 6,
                 },
                 'genome': {
                     'aa': 'X',
                     'codon': 'A',
                     'frame': 0,
-                    'offset': 6,
+                    'id': 'genId',
+                    'aaOffset': 2,
+                    'ntOffset': 6,
                 }
             },
             genome.offsetInfo(6))
@@ -790,13 +809,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'X',
                     'codon': 'AT',
                     'frame': 1,
-                    'offset': 7,
+                    'id': 'refId',
+                    'aaOffset': 2,
+                    'ntOffset': 7,
                 },
                 'genome': {
                     'aa': 'X',
                     'codon': 'AT',
                     'frame': 1,
-                    'offset': 7,
+                    'id': 'genId',
+                    'aaOffset': 2,
+                    'ntOffset': 7,
                 }
             },
             genome.offsetInfo(7))
@@ -827,13 +850,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'S',
                     'codon': 'TCC',
                     'frame': 0,
-                    'offset': 5,
+                    'id': 'refId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 },
                 'genome': {
                     'aa': 'T',
                     'codon': 'ACG',
                     'frame': 0,
-                    'offset': 5,
+                    'id': 'genId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 }
             },
             genome.offsetInfo(3, relativeToFeature=True,
@@ -866,13 +893,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'S',
                     'codon': 'TCC',
                     'frame': 0,
-                    'offset': 5,
+                    'id': 'refId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 },
                 'genome': {
                     'aa': 'T',
                     'codon': 'ACG',
                     'frame': 0,
-                    'offset': 5,
+                    'id': 'genId',
+                    'aaOffset': 1,
+                    'ntOffset': 5,
                 }
             },
             genome.offsetInfo(1, aa=True, relativeToFeature=True,
@@ -902,13 +933,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'V',
                     'codon': 'GTT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'refId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 },
                 'genome': {
                     'aa': '-',
                     'codon': '-TT',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'genId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 }
             },
             genome.offsetInfo(0))
@@ -940,13 +975,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'V',
                     'codon': 'GTT',
                     'frame': 1,
-                    'offset': 1,
+                    'id': 'refId',
+                    'aaOffset': 0,
+                    'ntOffset': 1,
                 },
                 'genome': {
                     'aa': 'F',
                     'codon': 'TTC',
                     'frame': 0,
-                    'offset': 0,
+                    'id': 'genId',
+                    'aaOffset': 0,
+                    'ntOffset': 0,
                 }
             },
             genome.offsetInfo(1))
@@ -986,13 +1025,17 @@ class TestOffsetInfo(TestCase):
                     'aa': 'I',
                     'codon': 'ATT',
                     'frame': 0,
-                    'offset': 8,
+                    'id': 'refId',
+                    'aaOffset': 2,
+                    'ntOffset': 8,
                 },
                 'genome': {
                     'aa': 'I',
                     'codon': 'ATT',
                     'frame': 0,
-                    'offset': 7,
+                    'id': 'genId',
+                    'aaOffset': 2,
+                    'ntOffset': 7,
                 }
             },
             genome.offsetInfo(2, featureName='surface glycoprotein', aa=True,
@@ -1034,13 +1077,17 @@ class TestOffsetInfo(TestCase):
                         'aa': 'I',
                         'codon': 'ATT',
                         'frame': frame,
-                        'offset': 8 + frame,
+                        'id': 'refId',
+                        'aaOffset': 2,
+                        'ntOffset': 8 + frame,
                     },
                     'genome': {
                         'aa': 'I',
                         'codon': 'ATT',
                         'frame': frame,
-                        'offset': 7 + frame,
+                        'id': 'genId',
+                        'aaOffset': 2,
+                        'ntOffset': 7 + frame,
                     }
                 },
                 genome.offsetInfo(6 + frame,
@@ -1080,13 +1127,19 @@ class TestOffsetInfo(TestCase):
                         'aa': 'N',
                         'codon': 'AAT',
                         'frame': frame,
-                        'offset': start + offset,
+                        'id': 'NC_045512.2',
+                        'aaOffset': 500,
+                        'ntOffset': start + offset,
                     },
                     'genome': {
                         'aa': 'Y',
                         'codon': 'TAT',
                         'frame': frame,
-                        'offset': expectedGenomeOffset,
+                        'id': ALPHA_ID,
+                        # Alpha has 3 deletions before site 501 (at 69, 70,
+                        # and 144).
+                        'aaOffset': 497,
+                        'ntOffset': expectedGenomeOffset,
                     }
                 },
                 genome.offsetInfo(offset, relativeToFeature=True,
@@ -1108,7 +1161,6 @@ class TestOffsetInfo(TestCase):
                 offset - genome.genomeAligned.sequence[
                     :genome.gappedOffsets[offset]].count('-'))
             self.assertEqual(22990 + frame, expectedGenomeOffset)
-
             self.assertEqual(
                 {
                     'alignmentOffset': offset,
@@ -1118,13 +1170,19 @@ class TestOffsetInfo(TestCase):
                         'aa': 'N',
                         'codon': 'AAT',
                         'frame': frame,
-                        'offset': offset,
+                        'id': 'NC_045512.2',
+                        'aaOffset': 500,
+                        'ntOffset': offset,
                     },
                     'genome': {
                         'aa': 'Y',
                         'codon': 'TAT',
                         'frame': frame,
-                        'offset': expectedGenomeOffset,
+                        'id': ALPHA_ID,
+                        # Alpha has 3 deletions before site 501 (at 69, 70,
+                        # and 144).
+                        'aaOffset': 497,
+                        'ntOffset': expectedGenomeOffset,
                     }
                 },
                 genome.offsetInfo(offset, featureName='spike'))
@@ -1154,13 +1212,19 @@ class TestOffsetInfo(TestCase):
                     'aa': 'N',
                     'codon': 'AAT',
                     'frame': 0,
-                    'offset': start + offset * 3,
+                    'id': 'NC_045512.2',
+                    'aaOffset': offset,
+                    'ntOffset': start + offset * 3,
                 },
                 'genome': {
                     'aa': 'Y',
                     'codon': 'TAT',
                     'frame': 0,
-                    'offset': expectedGenomeOffset,
+                    'id': ALPHA_ID,
+                    # Alpha has 3 deletions before site 501 (at 69, 70,
+                    # and 144).
+                    'aaOffset': offset - 3,
+                    'ntOffset': expectedGenomeOffset,
                 }
             },
             genome.offsetInfo(offset, aa=True, relativeToFeature=True,
